<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/compresseur?lang_cible=ru
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// I
	'info_compresseur_titre' => 'Оптимизация и сжатие исходного кода',
	'info_question_activer_compactage_css' => 'Сжатие CSS:',
	'info_question_activer_compactage_js' => 'Сжатие Javascript:',
	'item_compresseur_closure' => 'Использовать Google Closure Compiler ',
	'item_compresseur_css' => 'Сжимать файлы CSS',
	'item_compresseur_js' => 'Сжимать javascript',

	// T
	'texte_compacter_avertissement' => 'Внимание! При включенном сжатии css и javascript файлов крайне затруднена отладка исходного кода. Используйте эти настройки после окончания работ по созданию сайта.',
	'texte_compacter_script_css' => 'Для ускорения времени загрузки сайта SPIP может объединять и сжимать (минимизировать) Javascript  и CSS файлы.',
	'titre_compacter_script_css' => 'Сжатие javascript и CSS'
);

?>
